Re: [PATCH 0/11] renaming argv_array
- From
René Scharfe <l.s.r@web.de>
- Date
- Aug 12, 2020, 16:23 UTC
- Message-ID
- <045ea49b-7165-0f45-e670-a24bf648f880@web.de>
- In-Reply-To
- <20200812151038.GB33189@coredump.intra.peff.net>
Am 12.08.20 um 17:10 schrieb Jeff King:
Show 11 quoted lines
> On Wed, Aug 12, 2020 at 11:06:11AM -0400, Jeff King wrote: > >> Debian unstable now ships coccinelle 1.0.8, and it's unbelievably slow >> compared to 1.0.4. Running "make coccicheck" is currently at 80 minutes >> of CPU time running each script in parallel, with none of them down. >> They're also all consuming 6GB of RAM each, so I'm killing them all. > > This seems to be related to setting SPATCH_BATCH_SIZE to "0". It used to make > things go much faster (if you had enough memory), but now seems to just > consume tons of CPU. Setting it to "1" finishes the whole thing in ~13 > minutes of CPU (~2m wall-clock).
This bit me as well, and I settled with SPATCH_BATCH_SIZE = 10. With MAKEFLAGS += -j3 I get these number, which are quite similar to yours (except I don't dare use more cores due to cooling issues..):
real 4m12,393s user 12m15,447s sys 0m10,418s
> So that's at least a path forward, but in general I have been frustrated > with operational aspects of coccinelle like this.
And I was a bit shocked when Coccinelle's testing package became unmaintained for a while and I had to compile it from source.
And yes, coccicheck is quite heavy. When I merge all .cocci files into one I get:
real 2m7,164s user 2m5,389s sys 0m1,572s
Nice. With spatch -j3 I get basically the same numbers, though. Hmm.
René